#region Copyright Syncfusion Inc. 2001 - 2017
// Copyright Syncfusion Inc. 2001 - 2017. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Linq;

namespace CustomSummaries.Model
{
    public class DataPoint
    {
        public DataPoint(int id, string category, string item, string country, string state, decimal currency,
            double value1, double value2, double value3)
        {
            this.ID = id;
            this.Category = category;
            this.Item = item;
            this.Country = country;
            this.State = state;
            this.Currency = currency;
        }

        public int ID { get; private set; }
        public string Country { get; private set; }
        public string State { get; private set; }
        public string Category { get; private set; }
        public string Item { get; private set; }
        public decimal Currency { get; private set; }
    }

    enum Shape
    {
        Point,
        Line,
        Triangle,
        Square,
        Rectangle,
        Trapezoid,
        Pentagon
    }

    class BusinessObjectCollection : List<BusinessObject>
    {
        public static BusinessObjectCollection GetList(int count)
        {
            BusinessObjectCollection list = new BusinessObjectCollection();

            List<string> Fruits = new List<string>(new string[] { "cherry", "mango" });
            List<string> Colors = new List<string>(new string[] { "red", "green"});
            List<string> Categories = new List<string>(new string[] { "Animals" });
            List<string> Items = new List<string>(new string[] { "Dog", "Pig", "Horse", "Cow" });
            // Geography
            string[] countries = new string[] { "Australia", "Canada", "France", "Germany" };
            string[] ausStates = new string[] { "New South Wales", "Queensland" };
            string[] canadaStates = new string[] { "Alberta", "British Columbia"};
            string[] franceStates = new string[] { "Charente Maritime", "Essonne"};
            string[] germanyStates = new string[] { "Bayern", "Brandenburg", "Hamburg" };
            string[] ukStates = new string[] { "England" };
            string[] ussStates = new string[] { "New York", "North Carolina", };

            // Time
            string[] dates = new string[] {"FY 2008", "FY 2009" };

            // Products
            string[] products = new string[] { "Bike", "Car" };

            Random r = new Random(123123);
            int shapeCount = Enum.GetNames(typeof(Shape)).Count();

            for (int i = 0; i < count; ++i)
            {
                BusinessObject bo = new BusinessObject()
                {
                    Fruit = Fruits[r.Next(Fruits.Count)],
                    Shape = (Shape)r.Next(shapeCount),
                    Color = Colors[r.Next(Colors.Count)],
                    Country = countries[r.Next(1, countries.GetLength(0))],
                    Date = dates[r.Next(r.Next(dates.GetLength(0) + 1))],
                    Product = products[r.Next(r.Next(products.GetLength(0) + 1))],
                    Category = Categories[r.Next(Categories.Count)],
                    Item = Items[r.Next(Items.Count)],
                    State = products[r.Next(r.Next(products.GetLength(0) + 1))],
                    Weight = ((int)(r.NextDouble() * 1000)) / 10d,
                    Even = r.Next(2) == 0,
                    Count = r.Next(4) + 1,
                    Section = r.Next(6)
                };
                switch (bo.Country)
                {
                    case "Australia":
                        {
                            bo.State = ausStates[r.Next(ausStates.GetLength(0))];
                            break;
                        }
                    case "Canada":
                        {
                            bo.State = canadaStates[r.Next(canadaStates.GetLength(0))];
                            break;
                        }
                    case "France":
                        {
                            bo.State = franceStates[r.Next(franceStates.GetLength(0))];
                            break;
                        }
                    case "Germany":
                        {
                            bo.State = germanyStates[r.Next(germanyStates.GetLength(0))];
                            break;
                        }
                    case "United Kingdom":
                        {
                            bo.State = ukStates[r.Next(ukStates.GetLength(0))];
                            break;
                        }
                    case "United States":
                        {
                            bo.State = ussStates[r.Next(ussStates.GetLength(0))];
                            break;
                        }
                }
                list.Add(bo);
            }
            return list;
        }
    }

    class BusinessObject
    {
        public string Fruit { get; set; }
        public string Color { get; set; }
        public Shape Shape { get; set; }
        public bool Even { get; set; }
        public int Section { get; set; }
        public double Weight { get; set; }
        public int Count { get; set; }
        public string Country { get; set; }
        public string State { get; set; }
        public string Category { get; set; }
        public string Item { get; set; }
        public string Product { get; set; }
        public string Date { get; set; }

        public override string ToString()
        {
            return string.Format("Fruit=[{0}] Color=[{1}] Shape=[{2}] Even=[{3}] Section=[{4}] Weight=[{5:0.0}] Count=[{6}]", this.Fruit, this.Color, this.Shape, this.Even, this.Section, this.Weight, this.Count);
        }

    }

    class BusinessObjectsDataView : DataView
    {
        public static DataView GetDataTable(int count)
        {
            DataTable dt = new DataTable("BusinessObjectsDataTable");
            PropertyDescriptorCollection pdc = TypeDescriptor.GetProperties(typeof(BusinessObject));
            foreach (PropertyDescriptor pd in pdc)
            {
                dt.Columns.Add(new DataColumn(pd.Name, pd.PropertyType));
            }
            BusinessObjectCollection list = BusinessObjectCollection.GetList(count);
            foreach (BusinessObject bo in list)
            {
                DataRow dr = dt.NewRow();
                foreach (PropertyDescriptor pd in pdc)
                {
                    dr[pd.Name] = pd.GetValue(bo);
                }
                dt.Rows.Add(dr);
            }
            return dt.DefaultView;
        }
    }
}